==> estateplat-common-1.2.4-20191204.054700-203-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtYh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * Created by zdd on 2016/1/20.
 * 银行信息属性
 */
@Table(name = "bdc_xt_yh")
public class BdcXtYh implements Serializable {
    @Id
    private String yhid;
    private String yhmc;
    private String zjlx;
    private String zjbh;
    private String bz;
    private String txdz;//通讯地址
    private String yb;//邮编
    private String fzr;//负责人
    private String fzrlxdh;//负责人联系电话
    private String dwdm;//单位代码
    private String sfgz;//是否挂账
    private String sftysf;//是否统一收费

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 银行编号，具有唯一约束。编号规则：银行缩写_行政区代码，比如，ICBC_3201，表示中国工商银行南京分行
     */
    private String yhbh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 上级银行id，即父银行id
     */
    private String sjyhid;

    private String yhfr;//银行法人

    private String yhfrzjzl;//银行法人证件种类

    private String yhfrzjh;//银行法人证件号

    private String yhfrdh;//银行法人电话

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getFzrlxdh() {
        return fzrlxdh;
    }

    public void setFzrlxdh(String fzrlxdh) {
        this.fzrlxdh = fzrlxdh;
    }

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYhbh() {
        return yhbh;
    }

    public void setYhbh(String yhbh) {
        this.yhbh = yhbh;
    }

    public String getSjyhid() {
        return sjyhid;
    }

    public void setSjyhid(String sjyhid) {
        this.sjyhid = sjyhid;
    }

    public String getYhfr() {
        return yhfr;
    }

    public void setYhfr(String yhfr) {
        this.yhfr = yhfr;
    }

    public String getSfgz() {
        return sfgz;
    }

    public void setSfgz(String sfgz) {
        this.sfgz = sfgz;
    }

    public String getSftysf() {
        return sftysf;
    }

    public void setSftysf(String sftysf) {
        this.sftysf = sftysf;
    }

    public String getYhfrzjzl() {
        return yhfrzjzl;
    }

    public void setYhfrzjzl(String yhfrzjzl) {
        this.yhfrzjzl = yhfrzjzl;
    }

    public String getYhfrzjh() {
        return yhfrzjh;
    }

    public void setYhfrzjh(String yhfrzjh) {
        this.yhfrzjh = yhfrzjh;
    }

    public String getYhfrdh() {
        return yhfrdh;
    }

    public void setYhfrdh(String yhfrdh) {
        this.yhfrdh = yhfrdh;
    }
}

==> estateplat-common-1.2.4-20191226.025401-231-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtYh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * Created by zdd on 2016/1/20.
 * 银行信息属性
 */
@Table(name = "bdc_xt_yh")
public class BdcXtYh implements Serializable {
    @Id
    private String yhid;
    private String yhmc;
    private String zjlx;
    private String zjbh;
    private String bz;
    private String txdz;//通讯地址
    private String yb;//邮编
    private String fzr;//负责人
    private String fzrlxdh;//负责人联系电话
    private String dwdm;//单位代码
    private String sfgz;//是否挂账
    private String sftysf;//是否统一收费
    private String sfjcpttysf;//是否集成平台统一收费

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 银行编号，具有唯一约束。编号规则：银行缩写_行政区代码，比如，ICBC_3201，表示中国工商银行南京分行
     */
    private String yhbh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 上级银行id，即父银行id
     */
    private String sjyhid;

    private String yhfr;//银行法人

    private String yhfrzjzl;//银行法人证件种类

    private String yhfrzjh;//银行法人证件号

    private String yhfrdh;//银行法人电话

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getFzrlxdh() {
        return fzrlxdh;
    }

    public void setFzrlxdh(String fzrlxdh) {
        this.fzrlxdh = fzrlxdh;
    }

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYhbh() {
        return yhbh;
    }

    public void setYhbh(String yhbh) {
        this.yhbh = yhbh;
    }

    public String getSjyhid() {
        return sjyhid;
    }

    public void setSjyhid(String sjyhid) {
        this.sjyhid = sjyhid;
    }

    public String getYhfr() {
        return yhfr;
    }

    public void setYhfr(String yhfr) {
        this.yhfr = yhfr;
    }

    public String getSfgz() {
        return sfgz;
    }

    public void setSfgz(String sfgz) {
        this.sfgz = sfgz;
    }

    public String getSftysf() {
        return sftysf;
    }

    public void setSftysf(String sftysf) {
        this.sftysf = sftysf;
    }

    public String getYhfrzjzl() {
        return yhfrzjzl;
    }

    public void setYhfrzjzl(String yhfrzjzl) {
        this.yhfrzjzl = yhfrzjzl;
    }

    public String getYhfrzjh() {
        return yhfrzjh;
    }

    public void setYhfrzjh(String yhfrzjh) {
        this.yhfrzjh = yhfrzjh;
    }

    public String getYhfrdh() {
        return yhfrdh;
    }

    public void setYhfrdh(String yhfrdh) {
        this.yhfrdh = yhfrdh;
    }

    public String getSfjcpttysf() {
        return sfjcpttysf;
    }

    public void setSfjcpttysf(String sfjcpttysf) {
        this.sfjcpttysf = sfjcpttysf;
    }
}
